@@ -1,21 +1,9 @@
-/* This file is part of the KDE project
-   Copyright (C) 1998, 1999 Torben Weis <weis@kde.org>
-   Copyright (C) 2006 Daniel Teske <teske@squorn.de>
+/*
+    This file is part of the KDE project
+    SPDX-FileCopyrightText: 1998, 1999 Torben Weis <weis@kde.org>
+    SPDX-FileCopyrightText: 2006 Daniel Teske <teske@squorn.de>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "kbookmarkmenu.h"
@@ -24,17 +12,18 @@
 #include "kbookmarkaction.h"
 #include "kbookmarkactionmenu.h"
 #include "kbookmarkcontextmenu.h"
-#include "kbookmarks_debug.h"
 #include "kbookmarkdialog.h"
 #include "kbookmarkowner.h"
+#include "kbookmarks_debug.h"
 
+#if KBOOKMARKS_BUILD_DEPRECATED_SINCE(5, 69)
 #include <KActionCollection>
+#endif
 #include <KAuthorized>
 #include <KStandardAction>
 
 #include <QApplication>
 #include <QMenu>
-#include <QObject>
 #include <QStandardPaths>
 
 /********************************************************************/
@@ -43,69 +32,57 @@
 class KBookmarkMenuPrivate
 {
 public:
-    KBookmarkMenuPrivate()
-        : newBookmarkFolderAction(nullptr),
-          addBookmarkAction(nullptr),
-          bookmarksToFolderAction(nullptr),
-          editBookmarksAction(nullptr),
-          numberOfOpenTabs(2)
-    {
-    }
-
-    QAction *newBookmarkFolderAction;
-    QAction *addBookmarkAction;
-    QAction *bookmarksToFolderAction;
-    QAction *editBookmarksAction;
-    int numberOfOpenTabs;
+    QAction *newBookmarkFolderAction = nullptr;
+    QAction *addBookmarkAction = nullptr;
+    QAction *bookmarksToFolderAction = nullptr;
+    QAction *editBookmarksAction = nullptr;
+    int numberOfOpenTabs = 2;
 };
 
 #if KBOOKMARKS_BUILD_DEPRECATED_SINCE(5, 69)
-KBookmarkMenu::KBookmarkMenu(KBookmarkManager *mgr,
-                             KBookmarkOwner *_owner,
-                             QMenu *_parentMenu,
-                             KActionCollection *actionCollection)
-    : QObject(),
-      m_actionCollection(actionCollection),
-      d(new KBookmarkMenuPrivate()),
-      m_bIsRoot(true),
-      m_pManager(mgr),
-      m_pOwner(_owner),
-      m_parentMenu(_parentMenu),
-      m_parentAddress(QString())   //TODO KBookmarkAdress::root
+KBookmarkMenu::KBookmarkMenu(KBookmarkManager *mgr, KBookmarkOwner *_owner, QMenu *_parentMenu, KActionCollection *actionCollection)
+    : QObject()
+    , m_actionCollection(actionCollection)
+    , d(new KBookmarkMenuPrivate())
+    , m_bIsRoot(true)
+    , m_pManager(mgr)
+    , m_pOwner(_owner)
+    , m_parentMenu(_parentMenu)
+    , m_parentAddress(QString()) // TODO KBookmarkAdress::root
 {
     init();
 }
 
 #endif
 
-KBookmarkMenu::KBookmarkMenu(KBookmarkManager* manager, KBookmarkOwner* _owner, QMenu* _parentMenu)
-    : QObject(),
-    m_actionCollection(new KActionCollection(this)),
-    d(new KBookmarkMenuPrivate()),
-    m_bIsRoot(true),
-    m_pManager(manager),
-    m_pOwner(_owner),
-    m_parentMenu(_parentMenu),
-    m_parentAddress(QString())   //TODO KBookmarkAdress::root
+KBookmarkMenu::KBookmarkMenu(KBookmarkManager *manager, KBookmarkOwner *_owner, QMenu *_parentMenu)
+    : QObject()
+#if KBOOKMARKS_BUILD_DEPRECATED_SINCE(5, 69)
+    , m_actionCollection(new KActionCollection(this))
+#endif
+    , d(new KBookmarkMenuPrivate())
+    , m_bIsRoot(true)
+    , m_pManager(manager)
+    , m_pOwner(_owner)
+    , m_parentMenu(_parentMenu)
+    , m_parentAddress(QString()) // TODO KBookmarkAdress::root
 {
     // TODO KDE5 find a QMenu equvalnet for this one
-    //m_parentMenu->setKeyboardShortcutsEnabled( true );
+    // m_parentMenu->setKeyboardShortcutsEnabled( true );
 
     init();
 }
 
 void KBookmarkMenu::init()
 {
-    connect(m_parentMenu, &QMenu::aboutToShow,
-            this, &KBookmarkMenu::slotAboutToShow);
+    connect(m_parentMenu, &QMenu::aboutToShow, this, &KBookmarkMenu::slotAboutToShow);
 
     if (KBookmarkSettings::self()->m_contextmenu) {
         m_parentMenu->setContextMenuPolicy(Qt::CustomContextMenu);
         connect(m_parentMenu, &QWidget::customContextMenuRequested, this, &KBookmarkMenu::slotCustomContextMenu);
     }
 
-    connect(m_pManager, &KBookmarkManager::changed,
-            this, &KBookmarkMenu::slotBookmarksChanged);
+    connect(m_pManager, &KBookmarkManager::changed, this, &KBookmarkMenu::slotBookmarksChanged);
 
     m_bDirty = true;
     addActions();
@@ -130,18 +107,17 @@ void KBookmarkMenu::addActions()
     }
 }
 
-KBookmarkMenu::KBookmarkMenu(KBookmarkManager *mgr,
-                             KBookmarkOwner *_owner,
-                             QMenu *_parentMenu,
-                             const QString &parentAddress)
-    : QObject(),
-      m_actionCollection(new KActionCollection(this)),
-      d(new KBookmarkMenuPrivate()),
-      m_bIsRoot(false),
-      m_pManager(mgr),
-      m_pOwner(_owner),
-      m_parentMenu(_parentMenu),
-      m_parentAddress(parentAddress)
+KBookmarkMenu::KBookmarkMenu(KBookmarkManager *mgr, KBookmarkOwner *_owner, QMenu *_parentMenu, const QString &parentAddress)
+    : QObject()
+#if KBOOKMARKS_BUILD_DEPRECATED_SINCE(5, 69)
+    , m_actionCollection(new KActionCollection(this))
+#endif
+    , d(new KBookmarkMenuPrivate())
+    , m_bIsRoot(false)
+    , m_pManager(mgr)
+    , m_pOwner(_owner)
+    , m_parentMenu(_parentMenu)
+    , m_parentAddress(parentAddress)
 {
     connect(_parentMenu, &QMenu::aboutToShow, this, &KBookmarkMenu::slotAboutToShow);
     if (KBookmarkSettings::self()->m_contextmenu) {
@@ -155,7 +131,6 @@ KBookmarkMenu::~KBookmarkMenu()
 {
     qDeleteAll(m_lstSubMenus);
     qDeleteAll(m_actions);
-    delete d;
 }
 
 void KBookmarkMenu::ensureUpToDate()
@@ -242,7 +217,6 @@ QMenu *KBookmarkMenu::parentMenu() const
 /********************************************************************/
 /********************************************************************/
 
-
 /********************************************************************/
 /********************************************************************/
 /********************************************************************/
@@ -251,12 +225,11 @@ void KBookmarkMenu::slotBookmarksChanged(const QString &groupAddress)
 {
     qCDebug(KBOOKMARKS_LOG) << "KBookmarkMenu::slotBookmarksChanged groupAddress: " << groupAddress;
     if (groupAddress == m_parentAddress) {
-        //qCDebug(KBOOKMARKS_LOG) << "KBookmarkMenu::slotBookmarksChanged -> setting m_bDirty on " << groupAddress;
+        // qCDebug(KBOOKMARKS_LOG) << "KBookmarkMenu::slotBookmarksChanged -> setting m_bDirty on " << groupAddress;
         m_bDirty = true;
     } else {
         // Iterate recursively into child menus
-        for (QList<KBookmarkMenu *>::iterator it = m_lstSubMenus.begin(), end = m_lstSubMenus.end();
-                it != end; ++it) {
+        for (QList<KBookmarkMenu *>::iterator it = m_lstSubMenus.begin(), end = m_lstSubMenus.end(); it != end; ++it) {
             (*it)->slotBookmarksChanged(groupAddress);
         }
     }
@@ -267,8 +240,7 @@ void KBookmarkMenu::clear()
     qDeleteAll(m_lstSubMenus);
     m_lstSubMenus.clear();
 
-    for (QList<QAction *>::iterator it = m_actions.begin(), end = m_actions.end();
-            it != end; ++it) {
+    for (QList<QAction *>::iterator it = m_actions.begin(), end = m_actions.end(); it != end; ++it) {
         m_parentMenu->removeAction(*it);
         delete *it;
     }
@@ -279,7 +251,7 @@ void KBookmarkMenu::clear()
 
 void KBookmarkMenu::refill()
 {
-    //qCDebug(KBOOKMARKS_LOG) << "KBookmarkMenu::refill()";
+    // qCDebug(KBOOKMARKS_LOG) << "KBookmarkMenu::refill()";
     if (m_bIsRoot) {
         addActions();
     }
@@ -291,8 +263,7 @@ void KBookmarkMenu::refill()
 
 void KBookmarkMenu::addOpenInTabs()
 {
-    if (!m_pOwner || !m_pOwner->supportsTabs() ||
-            !KAuthorized::authorizeAction(QStringLiteral("bookmarks"))) {
+    if (!m_pOwner || !m_pOwner->supportsTabs() || !KAuthorized::authorizeAction(QStringLiteral("bookmarks"))) {
         return;
     }
 
@@ -310,8 +281,8 @@ void KBookmarkMenu::addOpenInTabs()
 
 void KBookmarkMenu::addAddBookmarksList()
 {
-    if (!m_pOwner || !m_pOwner->enableOption(KBookmarkOwner::ShowAddBookmark) || !m_pOwner->supportsTabs() ||
-            (d->numberOfOpenTabs < 2) || !KAuthorized::authorizeAction(QStringLiteral("bookmarks"))) {
+    if (!m_pOwner || !m_pOwner->enableOption(KBookmarkOwner::ShowAddBookmark) || !m_pOwner->supportsTabs() || (d->numberOfOpenTabs < 2)
+        || !KAuthorized::authorizeAction(QStringLiteral("bookmarks"))) {
         return;
     }
 
@@ -328,9 +299,11 @@ void KBookmarkMenu::addAddBookmarksList()
         d->bookmarksToFolderAction->setStatusTip(d->bookmarksToFolderAction->toolTip());
         connect(d->bookmarksToFolderAction, &QAction::triggered, this, &KBookmarkMenu::slotAddBookmarksList);
 
+#if KBOOKMARKS_BUILD_DEPRECATED_SINCE(5, 69)
         if (m_actionCollection) {
             m_actionCollection->addAction(d->bookmarksToFolderAction->objectName(), d->bookmarksToFolderAction);
         }
+#endif
     }
 
     m_parentMenu->addAction(d->bookmarksToFolderAction);
@@ -338,8 +311,7 @@ void KBookmarkMenu::addAddBookmarksList()
 
 void KBookmarkMenu::addAddBookmark()
 {
-    if (!m_pOwner || !m_pOwner->enableOption(KBookmarkOwner::ShowAddBookmark) ||
-            !KAuthorized::authorizeAction(QStringLiteral("bookmarks"))) {
+    if (!m_pOwner || !m_pOwner->enableOption(KBookmarkOwner::ShowAddBookmark) || !KAuthorized::authorizeAction(QStringLiteral("bookmarks"))) {
         return;
     }
 
@@ -349,9 +321,11 @@ void KBookmarkMenu::addAddBookmark()
             d->addBookmarkAction->setObjectName(QStringLiteral("add_bookmark"));
         }
 
+#if KBOOKMARKS_BUILD_DEPRECATED_SINCE(5, 69)
         if (m_actionCollection) {
             m_actionCollection->addAction(d->addBookmarkAction->objectName(), d->addBookmarkAction);
         }
+#endif
 
         if (!m_bIsRoot) {
             d->addBookmarkAction->setShortcut(QKeySequence());
@@ -363,9 +337,8 @@ void KBookmarkMenu::addAddBookmark()
 
 void KBookmarkMenu::addEditBookmarks()
 {
-    if ((m_pOwner && !m_pOwner->enableOption(KBookmarkOwner::ShowEditBookmark)) ||
-            QStandardPaths::findExecutable(QStringLiteral(KEDITBOOKMARKS_BINARY)).isEmpty() ||
-            !KAuthorized::authorizeAction(QStringLiteral("bookmarks"))) {
+    if ((m_pOwner && !m_pOwner->enableOption(KBookmarkOwner::ShowEditBookmark))
+        || QStandardPaths::findExecutable(QStringLiteral(KEDITBOOKMARKS_BINARY)).isEmpty() || !KAuthorized::authorizeAction(QStringLiteral("bookmarks"))) {
         return;
     }
 
@@ -376,15 +349,16 @@ void KBookmarkMenu::addEditBookmarks()
     d->editBookmarksAction->setToolTip(tr("Edit your bookmark collection in a separate window", "@info:tooltip"));
     d->editBookmarksAction->setStatusTip(d->editBookmarksAction->toolTip());
 
+#if KBOOKMARKS_BUILD_DEPRECATED_SINCE(5, 69)
     if (m_actionCollection) {
         m_actionCollection->addAction(d->editBookmarksAction->objectName(), d->editBookmarksAction);
     }
+#endif
 }
 
 void KBookmarkMenu::addNewFolder()
 {
-    if (!m_pOwner || !m_pOwner->enableOption(KBookmarkOwner::ShowAddBookmark) ||
-            !KAuthorized::authorizeAction(QStringLiteral("bookmarks"))) {
+    if (!m_pOwner || !m_pOwner->enableOption(KBookmarkOwner::ShowAddBookmark) || !KAuthorized::authorizeAction(QStringLiteral("bookmarks"))) {
         return;
     }
 
@@ -402,7 +376,6 @@ void KBookmarkMenu::addNewFolder()
     }
 
     m_parentMenu->addAction(d->newBookmarkFolderAction);
-
 }
 
 void KBookmarkMenu::fillBookmarks()
@@ -414,7 +387,7 @@ void KBookmarkMenu::fillBookmarks()
         m_parentMenu->addSeparator();
     }
 
-    for (KBookmark bm = parentBookmark.first(); !bm.isNull();  bm = parentBookmark.next(bm)) {
+    for (KBookmark bm = parentBookmark.first(); !bm.isNull(); bm = parentBookmark.next(bm)) {
         m_parentMenu->addAction(actionForBookmark(bm));
     }
 }
@@ -422,7 +395,7 @@ void KBookmarkMenu::fillBookmarks()
 QAction *KBookmarkMenu::actionForBookmark(const KBookmark &bm)
 {
     if (bm.isGroup()) {
-        //qCDebug(KBOOKMARKS_LOG) << "Creating bookmark submenu named " << bm.text();
+        // qCDebug(KBOOKMARKS_LOG) << "Creating bookmark submenu named " << bm.text();
         KActionMenu *actionMenu = new KBookmarkActionMenu(bm, this);
         m_actions.append(actionMenu);
         KBookmarkMenu *subMenu = new KBookmarkMenu(m_pManager, m_pOwner, actionMenu->menu(), bm.address());
@@ -434,7 +407,7 @@ QAction *KBookmarkMenu::actionForBookmark(const KBookmark &bm)
         m_actions.append(sa);
         return sa;
     } else {
-        //qCDebug(KBOOKMARKS_LOG) << "Creating bookmark menu item for " << bm.text();
+        // qCDebug(KBOOKMARKS_LOG) << "Creating bookmark menu item for " << bm.text();
         QAction *action = new KBookmarkAction(bm, m_pOwner, this);
         m_actions.append(action);
         return action;
@@ -472,7 +445,6 @@ void KBookmarkMenu::slotAddBookmark()
         parentBookmark.addBookmark(m_pOwner->currentTitle(), m_pOwner->currentUrl(), m_pOwner->currentIcon());
         m_pManager->emitChanged(parentBookmark);
     }
-
 }
 
 void KBookmarkMenu::slotOpenFolderInTabs()
@@ -483,7 +455,7 @@ void KBookmarkMenu::slotOpenFolderInTabs()
 void KBookmarkMenu::slotNewFolder()
 {
     if (!m_pOwner) {
-        return;    // this view doesn't handle bookmarks...
+        return; // this view doesn't handle bookmarks...
     }
     KBookmarkGroup parentBookmark = m_pManager->findByAddress(m_parentAddress).toGroup();
     Q_ASSERT(!parentBookmark.isNull());
@@ -492,12 +464,12 @@ void KBookmarkMenu::slotNewFolder()
     delete dlg;
 }
 
-QAction * KBookmarkMenu::addBookmarkAction() const
+QAction *KBookmarkMenu::addBookmarkAction() const
 {
     return d->addBookmarkAction;
 }
 
-QAction * KBookmarkMenu::bookmarkTabsAsFolderAction() const
+QAction *KBookmarkMenu::bookmarkTabsAsFolderAction() const
 {
     return d->bookmarksToFolderAction;
 }
@@ -507,7 +479,9 @@ QAction *KBookmarkMenu::newBookmarkFolderAction() const
     return d->newBookmarkFolderAction;
 }
 
-QAction * KBookmarkMenu::editBookmarksAction() const
+QAction *KBookmarkMenu::editBookmarksAction() const
 {
     return d->editBookmarksAction;
 }
+
+#include "moc_kbookmarkmenu.cpp"
